<?php

namespace Drupal\flot_views_time\Plugin\views\style;

use Drupal\core\form\FormStateInterface;
use Drupal\views\Plugin\views\style\StylePluginBase;

/**
 * Style plugin to render dates and values as a bar, scatter, or line chart.
 *
 * @ingroup views_style_plugins
 *
 * @ViewsStyle(
 *   id = "flot_views_time",
 *   title = @Translation("Time-series Chart"),
 *   help = @Translation("Render a set of data into a time series."),
 *   theme = "views_view_flot_views_time",
 *   display_types = { "normal" }
 * )
 */
class FlotTime extends StylePluginBase {

  /**
   * Set default options.
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['x'] = array('default' => '');
    $options['y'] = array('default' => '');
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);

    // Create an array of allowed columns from the data we know:
    $field_names = $this->displayHandler->getFieldLabels();
    $form['x'] = [
      '#title' => $this->t('The field that contains the time data'),
      '#type' => 'select',
      '#options' => $field_names,
      '#default_value' => $this->options['x'],
    ];
    $form['y'] = [
      '#title' => $this->t('The field that contains the chart data'),
      '#type' => 'select',
      '#options' => $field_names,
      '#default_value' => $this->options['y'],
    ];
    $form['points'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display Points'),
      '#description' => $this->t('Display data points.'),
      '#default_value' => $this->options['points'],
    ];
    $form['lines'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display Lines'),
      '#description' => $this->t('Display Lines.'),
      '#default_value' => $this->options['lines'],
    ];
  }

}
